#include "mainwindow.h"



MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{

    setWindowTitle("Hello Cube");

    menuBar = new QMenuBar();
    toolBar = new QToolBar("Shading",this);
    statusBar = new QStatusBar(this);

    //File Menu Actions
    fileMenu = new QMenu("&File");
    shadingMenu= new QMenu("Shading");
    shadingGroup = new QActionGroup(shadingMenu);

    //Shader Menu Actions
    exitAction = new QAction("E&xit",fileMenu);
    exitAction->setShortcut(QKeySequence::Quit);
    connect(exitAction, SIGNAL(triggered()), this, SLOT(close()));

    noneAction = new QAction("None",shadingMenu);
    noneAction->setShortcut(QKeySequence("Ctrl+1"));
    noneAction->setCheckable(true);
    noneAction->setIcon(QIcon(":/img/wireframe.png"));
    shadingGroup->addAction(noneAction);

    flatAction = new QAction("Flat",shadingMenu);
    flatAction->setShortcut(QKeySequence("Ctrl+2"));
    flatAction->setCheckable(true);
    flatAction->setChecked(true);
    flatAction->setIcon(QIcon(":/img/flat.png"));
    shadingGroup->addAction(flatAction);

    gouraudAction = new QAction("Gouraud",shadingMenu);
    gouraudAction->setShortcut(QKeySequence("Ctrl+3"));
    gouraudAction->setCheckable(true);
    gouraudAction->setIcon(QIcon(":/img/gouraud.png"));
    shadingGroup->addAction(gouraudAction);

    phongAction = new QAction("Phong",shadingMenu);
    phongAction->setShortcut(QKeySequence("Ctrl+4" ));
    phongAction->setCheckable(true);
    phongAction->setIcon(QIcon(":/img/phong.png"));
    shadingGroup->addAction(phongAction);

    //Other Actions
    aboutAction = new QAction("About",menuBar);
    connect(aboutAction,SIGNAL(triggered()),this,SLOT(showAboutBox()));

    camHome = new QAction(QIcon(":/img/cam_home.png"),"Cam Home", toolBar);

    // Assemble Menus
    fileMenu->addAction(exitAction);
    menuBar->addMenu(fileMenu);

    shadingMenu->addAction(noneAction);
    shadingMenu->addAction(flatAction);
    shadingMenu->addAction(gouraudAction);
    shadingMenu->addAction(phongAction);
    menuBar->addMenu(shadingMenu);

    menuBar->addAction(aboutAction);

    setMenuBar(menuBar);

    //Assemble Tool Bar
    toolBar->addAction(noneAction);
    toolBar->addAction(flatAction);
    toolBar->addAction(gouraudAction);
    toolBar->addAction(phongAction);
    toolBar->addAction(camHome);
    addToolBar( toolBar);

    statusBar->showMessage("Hello");
    setStatusBar(statusBar);

    //Main Widget
    mainWidget = new CubeWidget(this);
    setCentralWidget(mainWidget);



}

MainWindow::~MainWindow()
{

}

void MainWindow::showAboutBox()
{
 QMessageBox msgBox;
 msgBox.setWindowTitle("About Hello Cube!");
 msgBox.setText("Written by Kai Westerkamp");
 msgBox.exec();
}
